@@ -332,13 +332,28 @@ def move_files(dest: Union[str, bytes], *files: Union[str, bytes], force: bool =
         move(file, dest)
 
 
+def list_dir(folder: str = '.', filter: str = None, reverse: bool = False) -> List[str]:
+    """ List a directory and return a list with all file path of that directory that satisfy the given filter,
+        ordered alphabetically.
+
+    :param folder: The folder to list.
+    :param filter: The filter to apply.
+    :param reverse: If True, the list is inverted sorted. By default, False.
+    :return: The list with the path to each directory.
+    """
+    return sorted([
+        join(folder, file.name) for file in scandir(folder) if not filter or re.match(filter, file.name)
+    ], reverse=reverse)
+
+
 def first_file(folder: str = '.', filter: str = None) -> str:
     """ Obtain the first file name ordered alphabetically from a folder. By default, it uses the current folder.
     :param folder: The folder path with the files.
     :param filter: A regular expression pattern to filter the files. By default, all files are taking into account.
     :return: The first file name.
     """
-    return sorted([file.name for file in scandir(folder) if not filter or re.match(filter, file.name)])[0]
+    files = list_dir(folder, filter)
+    return files[0] if files else []
 
 
 def last_file(folder: str = '.', filter: str = None) -> str:
@@ -347,7 +362,8 @@ def last_file(folder: str = '.', filter: str = None) -> str:
     :param filter: A regular expression pattern to filter the files.
     :return: The last file name.
     """
-    return sorted([file.name for file in scandir(folder) if not filter or re.match(filter, file.name)], reverse=True)[0]
+    files = list_dir(folder, filter, True)
+    return files[0] if files else []
 
 
 class _Removable(object):
